@@ -22,7 +22,6 @@ KCupsRequest::KCupsRequest(KCupsConnection *connection)
     if (m_connection == nullptr) {
         m_connection = KCupsConnection::global();
     }
-    connect(this, &KCupsRequest::finished, &m_loop, &QEventLoop::quit);
 }
 
 QString KCupsRequest::serverError() const
@@ -254,9 +253,7 @@ void KCupsRequest::getPrinterPPD(const QString &printerName)
         do {
             const char *filename;
             filename = cupsGetPPD2(CUPS_HTTP_DEFAULT, qUtf8Printable(printerName));
-            qCDebug(LIBKCUPS) << filename;
             m_ppdFile = QString::fromUtf8(filename);
-            qCDebug(LIBKCUPS) << m_ppdFile;
         } while (m_connection->retry("/", CUPS_GET_PPD));
         setError(httpGetStatus(CUPS_HTTP_DEFAULT), cupsLastError(), QString::fromUtf8(cupsLastErrorString()));
         setFinished();
@@ -594,6 +591,10 @@ void KCupsRequest::waitTillFinished()
         return;
     }
 
+    if (!m_loopConnect) {
+        m_loopConnect = connect(this, &KCupsRequest::finished, &m_loop, &QEventLoop::quit);
+    }
+
     m_loop.exec();
 }
 
